# Bahasa Pemrograman Akz 🚀

**Akz** adalah bahasa pemrograman yang mudah digunakan untuk pemula.

---

## Fitur Utama ✨
- **Sintaks sederhana**: Menggunakan kata-kata sehari-hari seperti `jika`, `ulangi`, dan `tampilkan`.
- **Mudah dipasang**: Cukup install via `pip`.
- **Cross-platform**: Bisa dijalankan di Windows, macOS, Linux, dan Android.

---

## Instalasi dan Penggunaan 💻

### 1. Install Python (Jika Belum)
Install Python dari tautan berikut:
[Install_Python](https://www.python.org/downloads/)

### 2. Buat Folder Baru dan File Akz Baru
Buat folder baru dan file baru melalui File Manager atau Terminal.
```bash
mkdir (Nama Folder)
```

### 3. Coding pada File Akz
Mulai menulis kode pada file Akz yang baru dibuat.

### 4. Buka Terminal dan Install Akz
```bash
pip install akz-lang
```
Setelah selesai menulis kode, jalankan dengan perintah:
```bash
akz run (nama file)
```

Jika ada pertanyaan tentang AKZ, silakan hubungi pembuat/author melalui:
[WhatsApp](wa.me/6281288196028)
